package de.hhu.ba.yoshikoWrapper.core;

import java.util.Collection;
import java.util.HashMap;
import java.util.Locale;
import java.util.ResourceBundle;

public class LocalizationManager {
	
	//Locales
	static private final Locale usEnglish = new Locale("en","US");
	static private final Locale german = new Locale("de","DE");
	
    static private final HashMap<String, Locale> locales;
    static
    {
        locales = new HashMap<String, Locale>();
        locales.put("enUS", usEnglish);
        locales.put("deDE", german);
    }

	
	static private ResourceBundle currentBundle;
	
	static private Locale currentLocale = usEnglish;

	static public Collection<Locale> getLocales(){
		return locales.values();
	}
	
	static public String get(String key) {
		if (currentBundle == null) {
			currentBundle = ResourceBundle.getBundle("YoshikoStrings",currentLocale);
		}
		return currentBundle.getString(key);
	}
	
	static public void switchLanguage(Locale lcl) {
		currentLocale = lcl;
		updateBundle();
	}

	public static void switchLanguage(String key) {
		System.out.println("DEBUG: SWITCHING TO: "+key);
		currentLocale = locales.get(key);
		updateBundle();
	}
	
	private static void updateBundle() {
		currentBundle = ResourceBundle.getBundle("YoshikoStrings",currentLocale);
		CyCore.cm.getProperties().setProperty(
				"locale",
				currentLocale.getLanguage()+currentLocale.getCountry()
				);
	}

	public static Locale getCurrentLocale() {
		return currentLocale;
	}
}
